%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier de definition de la classe de documents
% exercices
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Cette classe s'utilise en commencant le document par
%\documentclass{exercices}
% et si on veut afficher les solutions par
%\documentclass[solutions]{exercices}

% Ensuite, on ecrit un exercice par
% \begin{exercice}\end{exercice}
% et ses solutions par
% \begin{solution}\end{solution}

% Les solutions ne sont affichees que si l'option [solutions] est donnee en en tete
% de la commande \documentclass

\LoadClass[a4paper,11pt]{article}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Variable qui dit si on souhaite
% afficher les solutions (1) ou non (0)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\affichesolution}{0}
\DeclareOption{solutions}
   {\renewcommand{\affichesolution}{1}}
\ProcessOptions

%%%%%%%%%%%%%%%%%%%%%%%%%%
% Choix des packages latex
%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{a4}
\RequirePackage[french]{babel}
\RequirePackage{array}
\RequirePackage{amsfonts,amssymb,amsmath, amscd,amsthm}
\RequirePackage{mathrsfs}
\RequirePackage{bbm}
\RequirePackage{ifthen}
\RequirePackage{comment}
\RequirePackage[all]{xy}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Definition des theoremes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\theoremstyle{definition}
\newtheorem{definition}{D\'efinition}
\newtheorem{exemple}{Exemple}
\theoremstyle{theorem}
\newtheorem{principe}{Principe}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Definition des commandes pour
% les caracteres mathematiques
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\R}{\mathbb{R}}
\newcommand{\C}{\mathbb{C}}
\newcommand{\Hb}{\mathbb{Hb}}
\newcommand{\Z}{\mathbb{Z}}
\newcommand{\Q}{\mathbb{Q}}
\newcommand{\N}{\mathbb{N}}
\newcommand{\F}{\mathbb{F}}
\newcommand{\A}{\mathbb{A}}
\renewcommand{\1}{\mathbbm{1}}

\newcommand{\Ens}{\textsc{(Ens)}}
\newcommand{\Grab}{\textsc{(Grab)}}
\newcommand{\Grp}{\textsc{(Grp)}}
\newcommand{\Anneaux}{\textsc{(Anneaux)}}
\newcommand{\Top}{\textsc{(Top)}}


\renewcommand{\Re}{\mathrm{Re}\,}
\renewcommand{\Im}{\mathrm{Im}\,}
\newcommand{\Log}{\mathrm{Log}\,}
\newcommand{\dlog}{\mathrm{dlog}\,}
\newcommand{\Hom}{\mathrm{Hom}}
\newcommand{\Aut}{\mathrm{Aut}}
\newcommand{\Ker}{\mathrm{Ker}}
\newcommand{\vect}{\mathrm{vect}}
\newcommand{\pgcd}{\mathrm{pgcd}}
\newcommand{\id}{\mathrm{id}}
\newcommand{\diag}{\mathrm{diag}}
\newcommand{\disc}{\mathrm{disc}}
\newcommand{\SL}{\mathrm{SL}}
\newcommand{\GL}{\mathrm{GL}}
\newcommand{\SO}{\mathrm{SO}}
\newcommand{\GA}{\mathrm{GA}}
\newcommand{\GSpin}{\mathrm{GSpin}}
\newcommand{\Spin}{\mathrm{Spin}}
\newcommand{\Cliff}{\mathrm{Cliff}}
\newcommand{\PGL}{\mathrm{PGL}}
\newcommand{\PSL}{\mathrm{PSL}}
\newcommand{\Nm}{\mathrm{Nm}}
\newcommand{\Gal}{\mathrm{Gal}}
\newcommand{\limproj}{\underset{\longleftarrow}{\lim}}
\newcommand{\limind}{\underset{\longrightarrow}{\lim}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Definition des commandes pour
% les caracteres arrondis
% Par convention, on ajoute c
% a la suite du caractere
% souhaite
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\Ac}{\mathcal{A}}
\newcommand{\Bc}{\mathcal{B}}
\newcommand{\Cc}{\mathcal{C}}
\newcommand{\Ec}{\mathcal{E}}
\newcommand{\Ic}{\mathcal{I}}
\newcommand{\Lc}{\mathcal{L}}
\newcommand{\Mc}{\mathcal{M}}
\newcommand{\Nc}{\mathcal{N}}
\newcommand{\Oc}{\mathcal{O}}
\newcommand{\Pc}{\mathcal{P}}
\newcommand{\Sc}{\mathcal{S}}
\newcommand{\Tc}{\mathcal{T}}

\newcommand{\Isc}{\mathscr{I}}
\newcommand{\Csc}{\mathscr{C}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Commandes mathematiques moins standards
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\Rbp}{\bar{\R}_+}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Correction des problemes d'accents
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def \é{\'e}
\def \è{\`{e}}
\def \ù{\`{u}}
\def \î{\^{\i}}
\def \à{\`{a}}
\def \ç{\c{c}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Mise en page a la main de la feuille d'exercices
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\parindent=0pt
\textwidth 17.0cm
\textheight25.0cm
\hoffset-2.0cm
\voffset-3.0cm

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Redefinition des labels pour les enumerations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\labelenumi}{\alph{enumi})\,}
\renewcommand{\labelenumii}{\roman{enumii})\,}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Definition d'une commande pour afficher l'annee suivante
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcounter{nextyear}
\setcounter{nextyear}{\number\year}
\addtocounter{nextyear}{1}
\newcommand{\nextyear}{\arabic{nextyear}}
		 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Definition des en-tetes et compteurs pour les exercices
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcounter{exercice}
\setcounter{exercice}{0}
\newenvironment {exercice}
		{\refstepcounter{exercice}
		 {\bf Exercice \arabic{exercice} : }}
		{\bigskip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Definition des en-tetes et compteurs pour les solutions
% On ne les affiche que si la commande \affichesolution
% ne vaut pas 0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcounter{solution}
\setcounter{solution}{0}

% On teste la variable affichesolution
\ifthenelse{\equal{\affichesolution}{0}}
% Si elle est egale a 0, on voit l'environnement solution
% comme un commentaire a exclure
	   {\excludecomment{solution}}
% Si la variable n'est pas egale a 0, on definit l'environnement
% solution pour qu'il s'affiche comme on le souhaite
	   {\newenvironment{solution}
		{\setcounter{solution}{\value{exercice}}
		\emph{Solution de l'exercice} \arabic{solution}.}
		{\bigskip}}

